# Automatically generated by SST
# pylint: disable=all
# ruff: noqa
from typing import Any

class Resource:
    class App:
        name: str
        stage: str
    class AuthEnvelopePrivateKey:
        type: str
        value: str
    class AuthEnvelopePublicKey:
        type: str
        value: str
    class BetterAuthSecret:
        type: str
        value: str
    class Config:
        API_HOST: str
        API_PORT: float
        API_URL: str
        API_VCS_PORT: float
        APP_HOST: str
        APP_PORT: float
        APP_URL: str
        DEPOT_DEFAULT_REPO_SIZE_LIMIT: float
        DEPOT_MAX_REPO_NAME_LENGTH: float
        DEPOT_REPO_ROOT: str
        DEV: bool
        NORTHSTAR_HOST: str
        NORTHSTAR_PORT: float
        NORTHSTAR_URL: str
        STAGE: str
        SUPPORT_EMAIL: str
        UPSTREAM_KMS_KEY_ARN: str
        VCS_HOST: str
        VCS_PORT: float
        VCS_URL: str
        type: str
    class DepotDB:
        database: str
        host: str
        password: str
        port: float
        type: str
        username: str
    class DepotService:
        service: str
        type: str
        url: str
    class DepotVPC:
        bastion: str
        type: str
    class DepotWeb:
        type: str
        url: str
    class GoogleClientId:
        type: str
        value: str
    class GoogleClientSecret:
        type: str
        value: str
    class GrafanaKey:
        type: str
        value: str
    class NorthstarInternalToken:
        type: str
        value: str
    class SlackWaitlistWebhookUrl:
        type: str
        value: str
    class VcsInternalSecret:
        type: str
        value: str
    class VcsService:
        service: str
        type: str
        url: str
    class WWWSite:
        type: str
        url: str
    class Waitlist:
        name: str
        type: str

